==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/ImageReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.ImageReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Image reference information. Used in the virtual machine profile.
 * @property id Image resource ID
 * @property offer The image offer if applicable.
 * @property publisher The image publisher
 * @property sku The image SKU
 * @property version The image version specified on creation.
 */
public data class ImageReferenceArgs(
    public val id: Output<String>? = null,
    public val offer: Output<String>? = null,
    public val publisher: Output<String>? = null,
    public val sku: Output<String>? = null,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.ImageReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.labservices.inputs.ImageReferenceArgs =
        com.pulumi.azurenative.labservices.inputs.ImageReferenceArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .offer(offer?.applyValue({ args0 -> args0 }))
            .publisher(publisher?.applyValue({ args0 -> args0 }))
            .sku(sku?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ImageReferenceArgs].
 */
@PulumiTagMarker
public class ImageReferenceArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var offer: Output<String>? = null

    private var publisher: Output<String>? = null

    private var sku: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value Image resource ID
     */
    @JvmName("mmisyvjvgmusgpwe")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The image offer if applicable.
     */
    @JvmName("xmwvchccaqwavqvl")
    public suspend fun offer(`value`: Output<String>) {
        this.offer = value
    }

    /**
     * @param value The image publisher
     */
    @JvmName("rwnqfemwelcgchsw")
    public suspend fun publisher(`value`: Output<String>) {
        this.publisher = value
    }

    /**
     * @param value The image SKU
     */
    @JvmName("okbhjrjalnujeeos")
    public suspend fun sku(`value`: Output<String>) {
        this.sku = value
    }

    /**
     * @param value The image version specified on creation.
     */
    @JvmName("cxmgvfewgvfgpocu")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value Image resource ID
     */
    @JvmName("ouuddgykxxkjnjmy")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The image offer if applicable.
     */
    @JvmName("rdkkfjrndtcrlcpa")
    public suspend fun offer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.offer = mapped
    }

    /**
     * @param value The image publisher
     */
    @JvmName("osrpfphtmojqviti")
    public suspend fun publisher(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisher = mapped
    }

    /**
     * @param value The image SKU
     */
    @JvmName("hhfuxuvfbxgoujpb")
    public suspend fun sku(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value The image version specified on creation.
     */
    @JvmName("mdtcdpwvyrclhdqu")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): ImageReferenceArgs = ImageReferenceArgs(
        id = id,
        offer = offer,
        publisher = publisher,
        sku = sku,
        version = version,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/labservices/kotlin/inputs/ImageReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.labservices.kotlin.inputs

import com.pulumi.azurenative.labservices.inputs.ImageReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Image reference information. Used in the virtual machine profile.
 * @property id Image resource ID
 * @property offer The image offer if applicable.
 * @property publisher The image publisher
 * @property sku The image SKU
 * @property version The image version specified on creation.
 */
public data class ImageReferenceArgs(
    public val id: Output<String>? = null,
    public val offer: Output<String>? = null,
    public val publisher: Output<String>? = null,
    public val sku: Output<String>? = null,
    public val version: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.labservices.inputs.ImageReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.labservices.inputs.ImageReferenceArgs =
        com.pulumi.azurenative.labservices.inputs.ImageReferenceArgs.builder()
            .id(id?.applyValue({ args0 -> args0 }))
            .offer(offer?.applyValue({ args0 -> args0 }))
            .publisher(publisher?.applyValue({ args0 -> args0 }))
            .sku(sku?.applyValue({ args0 -> args0 }))
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ImageReferenceArgs].
 */
@PulumiTagMarker
public class ImageReferenceArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    private var offer: Output<String>? = null

    private var publisher: Output<String>? = null

    private var sku: Output<String>? = null

    private var version: Output<String>? = null

    /**
     * @param value Image resource ID
     */
    @JvmName("dggonpnwaljlioku")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The image offer if applicable.
     */
    @JvmName("dpfgcpvsnatdnqrh")
    public suspend fun offer(`value`: Output<String>) {
        this.offer = value
    }

    /**
     * @param value The image publisher
     */
    @JvmName("whowfixuvmukoxib")
    public suspend fun publisher(`value`: Output<String>) {
        this.publisher = value
    }

    /**
     * @param value The image SKU
     */
    @JvmName("myahpxmrstrnlqih")
    public suspend fun sku(`value`: Output<String>) {
        this.sku = value
    }

    /**
     * @param value The image version specified on creation.
     */
    @JvmName("ajgigpeunjdbeddx")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value Image resource ID
     */
    @JvmName("kfxixprnxmvjunlj")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The image offer if applicable.
     */
    @JvmName("ievuqurtndpvquxf")
    public suspend fun offer(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.offer = mapped
    }

    /**
     * @param value The image publisher
     */
    @JvmName("fxeqjvmkxrltjvxk")
    public suspend fun publisher(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publisher = mapped
    }

    /**
     * @param value The image SKU
     */
    @JvmName("lsicfepfcvrcyqnk")
    public suspend fun sku(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value The image version specified on creation.
     */
    @JvmName("xwfblcpeuoxvoptt")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): ImageReferenceArgs = ImageReferenceArgs(
        id = id,
        offer = offer,
        publisher = publisher,
        sku = sku,
        version = version,
    )
}
